@@ -26,10 +26,25 @@
 #include <errno.h>
 #include "gdk-pixbuf-private.h"
 #include "gdk-pixbuf-animation.h"
-#include "gdk-pixbuf-alias.h"
 
 #include <glib/gstdio.h>
 
+/**
+ * SECTION:animation
+ * @Short_description: Animated images.
+ * @Title: Animations
+ * @See_also: #GdkPixbufLoader.
+ * 
+ * The &gdk-pixbuf; library provides a simple mechanism to load and represent
+ * animations. An animation is conceptually a series of frames to be displayed
+ * over time. Each frame is the same size. The animation may not be represented
+ * as a series of frames internally; for example, it may be stored as a 
+ * sprite and instructions for moving the sprite around a background. To display 
+ * an animation you don't need to understand its representation, however; you just
+ * ask &gdk-pixbuf; what should be displayed at a given point in time. 
+ * 
+ */
+
 typedef struct _GdkPixbufNonAnim GdkPixbufNonAnim;
 typedef struct _GdkPixbufNonAnimClass GdkPixbufNonAnimClass;
 
@@ -256,7 +271,7 @@ gdk_pixbuf_animation_new_from_file (const char *filename,
 #endif
 
 /**
- * gdk_pixbuf_animation_ref:
+ * gdk_pixbuf_animation_ref: (skip)
  * @animation: An animation.
  *
  * Adds a reference to an animation.
@@ -272,7 +287,7 @@ gdk_pixbuf_animation_ref (GdkPixbufAnimation *animation)
 }
 
 /**
- * gdk_pixbuf_animation_unref:
+ * gdk_pixbuf_animation_unref: (skip)
  * @animation: An animation.
  *
  * Removes a reference from an animation.
@@ -315,7 +330,7 @@ gdk_pixbuf_animation_is_static_image (GdkPixbufAnimation *animation)
  * sophisticated. If an animation hasn't loaded any frames yet, this
  * function will return %NULL.
  * 
- * Return value: unanimated image representing the animation
+ * Return value: (transfer none): unanimated image representing the animation
  **/
 GdkPixbuf*
 gdk_pixbuf_animation_get_static_image (GdkPixbufAnimation *animation)
@@ -411,7 +426,7 @@ gdk_pixbuf_animation_get_height (GdkPixbufAnimation *animation)
  *
  * A delay time of -1 is possible, indicating "infinite."
  * 
- * Return value: an iterator to move over the animation
+ * Return value: (transfer full): an iterator to move over the animation
  **/
 GdkPixbufAnimationIter*
 gdk_pixbuf_animation_get_iter (GdkPixbufAnimation *animation,
@@ -478,7 +493,7 @@ gdk_pixbuf_animation_iter_get_delay_time (GdkPixbufAnimationIter *iter)
  * (don't just add a reference), as it may get recycled as you advance
  * the iterator.
  *
- * Return value: the pixbuf to be displayed
+ * Return value: (transfer none): the pixbuf to be displayed
  **/
 GdkPixbuf*
 gdk_pixbuf_animation_iter_get_pixbuf (GdkPixbufAnimationIter *iter)
@@ -727,6 +742,3 @@ gdk_pixbuf_non_anim_iter_advance (GdkPixbufAnimationIter *iter,
         /* Advancing never requires a refresh */
         return FALSE;
 }
-
-#define __GDK_PIXBUF_ANIMATION_C__
-#include "gdk-pixbuf-aliasdef.c"
